/*
 *      Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 *      Licensed under the Flora License, Version 1.1 (the "License");
 *      you may not use this file except in compliance with the License.
 *      You may obtain a copy of the License at
 *
 *              http://floralicense.org/license/
 *
 *      Unless required by applicable law or agreed to in writing, software
 *      distributed under the License is distributed on an "AS IS" BASIS,
 *      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *      See the License for the specific language governing permissions and
 *      limitations under the License.
 */


/*
 * We must declare global variables to let the validator know the
 * global variables we use.
 * To declare global variables, write global variables along with
 * default values inside a comment on top of each source code.
 * The comment should start with the keyword, global.
 */

/*global isActive: true, getAlarmData: true*/

(function() {
  window.onload = function() {
    /**
     * Launch the Alarm application
     * @private
     */
    function launchWebApp(){
      var app = window.tizen.application.getCurrentApplication();
      var appId = app.appInfo.id.substring(0, (app.appInfo.id.lastIndexOf('.')) );
      window.tizen.application.launch(appId);
    }

    var addAlarm = document.getElementById('add-alarm');
    addAlarm.addEventListener('click', launchWebApp);

    var time = document.getElementById('current-time'),
        am_pm = document.getElementById('am-pm'),
        sun = document.getElementById('sun'),
        mon = document.getElementById('mon'),
        tue = document.getElementById('tue'),
        wed = document.getElementById('wed'),
        thu = document.getElementById('thu'),
        fri = document.getElementById('fri'),
        sat = document.getElementById('sat'),
        date = document.getElementById('date'),
        alarmIconOn = document.getElementById('alarm-icon-on'),
        alarmIconOff = document.getElementById('alarm-icon-off'),
        oneTimeAlarm = document.getElementById('one-time-alarm'),
        repeatAlarm = document.getElementById('repeat-alarm');

    /**
     * When clicking the alarm icon, this function is invoked
     * to activate/deactive the icon by setting it to the colored/gray icon, respectively.
     * @private
     */
    function toggleAlarm(){
        isActive = !isActive;

        alarmIconOn.style.display = isActive ? 'block' : 'none';
        alarmIconOff.style.display = isActive ? 'none' : 'block';
    }

    /*
     * Set the alarm based on the alarm data
     */
    var alarmData = getAlarmData();
    time.textContent = alarmData.time;
    am_pm.textContent = alarmData.amPm;
    if(alarmData.type === 'repeat') {
        sun.style.color = alarmData.sun === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        mon.style.color = alarmData.mon === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        tue.style.color = alarmData.tue === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        wed.style.color = alarmData.wed === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        thu.style.color = alarmData.thu === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        fri.style.color = alarmData.fri === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        sat.style.color = alarmData.sat === true ? 'rgb(77, 207, 255)' : 'rgb(184, 184, 184)';
        oneTimeAlarm.style.display = 'none';
        repeatAlarm.style.display = 'block';
    } else {
        date.textContent = alarmData.value;
        oneTimeAlarm.style.display = 'block';
        repeatAlarm.style.display = 'none';
    }

    alarmIconOn.style.display = isActive ? 'block' : 'none';
    alarmIconOff.style.display = isActive ? 'none' : 'block';

    alarmIconOn.addEventListener('click', toggleAlarm);
    alarmIconOff.addEventListener('click', toggleAlarm);


    /*
     * Show/hide the alarm according to the alarm data
     */
    var alarm = document.getElementById('alarm'),
        noAlarm = document.getElementById('no-alarm');
    if(alarmData.type !== 'noAlarm'){
        noAlarm.style.display = 'none';
        alarm.style.display = 'block';
    } else {
        noAlarm.style.display = 'block';
        alarm.style.display = 'none';
    }

    //add eventListener for tizenhwkey
    function keyEventHandler(event) {
        if (event.keyName === 'back') {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (ignore) {}
        }
    }
    document.addEventListener('tizenhwkey', keyEventHandler);
  };
}());
